@@ -1,5 +1,5 @@
-// Copyright 2008-present Contributors to the OpenImageIO project.
-// SPDX-License-Identifier: BSD-3-Clause
+// Copyright Contributors to the OpenImageIO project.
+// SPDX-License-Identifier: BSD-3-Clause and Apache-2.0
 // https://github.com/OpenImageIO/oiio
 
 // clang-format off
@@ -590,6 +590,11 @@ OIIO_NAMESPACE_END
 
 
 // Supply a fmtlib compatible custom formatter for TypeDesc.
+#if FMT_VERSION >= 100000
+FMT_BEGIN_NAMESPACE
+template<> struct formatter<OIIO::TypeDesc> : ostream_formatter {};
+FMT_END_NAMESPACE
+#else
 FMT_BEGIN_NAMESPACE
 template <>
 struct formatter<OIIO::TypeDesc> {
@@ -615,3 +620,4 @@ struct formatter<OIIO::TypeDesc> {
     }
 };
 FMT_END_NAMESPACE
+#endif
